@@ -7,10 +7,10 @@ import base64
 import pyperclip # 新增：用于操作剪贴板
 import platform  # 新增：用于检测操作系统
 from PIL import Image, ImageDraw
-from ..aient.src.aient.plugins import register_tool
+from ..aient.aient.plugins import register_tool
 
-from ..aient.src.aient.models import chatgpt
-from ..aient.src.aient.core.utils import get_image_message, get_text_message
+from ..aient.aient.models import chatgpt
+from ..aient.aient.core.utils import get_image_message, get_text_message
 
 def display_image_with_bounding_boxes_and_masks_py(
     original_image,
