@@ -1,7 +1,7 @@
 import requests
 import csv
 from datetime import datetime
-from ..aient.src.aient.plugins import register_tool
+from ..aient.aient.plugins import register_tool
 
 @register_tool()
 def search_arxiv(query, max_results=5, sort_by='relevance', sort_order='descending',
